isbndb library
Classes
- Author
- An object which returns the name of an author and the list of the books he published.
- AuthorQueryResult
- The object which contains the results of search in the authors database
- Book
- An object which handle the details of a book
- BookQueryResult
- The object which contains the results of search in the books database
- ISBNdb
- The main object for using the ISBNdb API You need to init the class with your own key See https://isbndb.com/isbn-database
- KeyDetails
-
Account details returned by the
/keyendpoint. - Merchant
- An object which returns the details about a seller of a book on the web.
- PlanLimit
- Usage limits attached to the current API plan.
- Publisher
- An object which returns the name of a publisher and the list of the books he published.
- PublisherQueryResult
- The object which contains the results of search in the publishers database
- Stats
-
Global API dataset statistics returned by
/stats. - Subject
- An object which returns the name of a subject and the list of the books related to this subject.
- SubjectQueryResult
- The object which contains the results of search in the subjects database
- UpdatedBook
-
A single book update entry returned by
/feeds/books/updates. - UpdatedBookFeed
- Paginated feed of recently updated ISBNs returned by ISBNdb.
Enums
- BookColumn
- The different types of search available for the books
Extensions
- AuthorPatterns on Author
- Adds pattern-matching-related methods to Author.
- AuthorQueryResultPatterns on AuthorQueryResult
- Adds pattern-matching-related methods to AuthorQueryResult.
- AuthorQueryResultX on AuthorQueryResult
- BookPatterns on Book
- Adds pattern-matching-related methods to Book.
- BookQueryResultPatterns on BookQueryResult
- Adds pattern-matching-related methods to BookQueryResult.
- BookQueryResultResultX on BookQueryResult
- KeyDetailsPatterns on KeyDetails
- Adds pattern-matching-related methods to KeyDetails.
- MerchantPatterns on Merchant
- Adds pattern-matching-related methods to Merchant.
- PlanLimitPatterns on PlanLimit
- Adds pattern-matching-related methods to PlanLimit.
- PublisherPatterns on Publisher
- Adds pattern-matching-related methods to Publisher.
- PublisherQueryResultPatterns on PublisherQueryResult
- Adds pattern-matching-related methods to PublisherQueryResult.
- PublisherQueryResultX on PublisherQueryResult
- StatsPatterns on Stats
- Adds pattern-matching-related methods to Stats.
- SubjectPatterns on Subject
- Adds pattern-matching-related methods to Subject.
- SubjectQueryResultPatterns on SubjectQueryResult
- Adds pattern-matching-related methods to SubjectQueryResult.
- SubjectQueryResultX on SubjectQueryResult
- UpdatedBookFeedPatterns on UpdatedBookFeed
- Adds pattern-matching-related methods to UpdatedBookFeed.
- UpdatedBookPatterns on UpdatedBook
- Adds pattern-matching-related methods to UpdatedBook.
Exceptions / Errors
- ISBNdbException
- Exception thrown when an ISBNdb API request fails.