datePublished property

  1. @JsonKey.new(name: 'date_published')
DateTime? get datePublished
inherited

Date when the book was published.

Partial API values are normalized to the start of their period: a year becomes January 1st and a year-month becomes the first day of the month.

Implementation

String? get language;/// Date when the book was published.
///
/// Partial API values are normalized to the start of their period: a year
/// becomes January 1st and a year-month becomes the first day of the month.
@_DateConverter()@JsonKey(name: 'date_published') DateTime? get datePublished;