Stats class sealed

Global API dataset statistics returned by /stats.

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

Stats({required int books, required int authors, required int publishers, required int subjects})
factory
Stats.fromJson(Map<String, dynamic> json)
Used to build the object from the response of the ISBNdb API.
factory

Properties

authors int
no setterinherited
books int
no setterinherited
copyWith → $StatsCopyWith<Stats>
Create a copy of Stats with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
publishers int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjects int
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_Stats value)) → TResult

Available on Stats, provided by the StatsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Stats value)?) → TResult?

Available on Stats, provided by the StatsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Stats value)?, {required TResult orElse()}) → TResult

Available on Stats, provided by the StatsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int books, int authors, int publishers, int subjects)?, {required TResult orElse()}) → TResult

Available on Stats, provided by the StatsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this Stats to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(int books, int authors, int publishers, int subjects)) → TResult

Available on Stats, provided by the StatsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int books, int authors, int publishers, int subjects)?) → TResult?

Available on Stats, provided by the StatsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited