updatedAt property

  1. @JsonKey.new(name: 'updated_at')
DateTime get updatedAt
inherited

Timestamp when the book was last updated by ISBNdb.

Implementation

String get isbn13;/// Timestamp when the book was last updated by ISBNdb.
@JsonKey(name: 'updated_at') DateTime get updatedAt;