UpdatedBookFeed class sealed

Paginated feed of recently updated ISBNs returned by ISBNdb.

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

UpdatedBookFeed({@JsonKey.new(name: 'data') @Default.new([]) List<UpdatedBook> updates, int? total, required int page, @JsonKey.new(name: 'page_size') required int pageSize})
factory
UpdatedBookFeed.fromJson(Map<String, dynamic> json)
Used to build the object from the response of the ISBNdb API.
factory

Properties

copyWith → $UpdatedBookFeedCopyWith<UpdatedBookFeed>
Create a copy of UpdatedBookFeed with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
page int
Current page number.
no setterinherited
pageSize int
Requested page size.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int?
Total number of updates available for the query, when provided.
no setterinherited
updates List<UpdatedBook>
Updated ISBN entries.
no setterinherited

Methods

debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
map<TResult extends Object?>(TResult $default(_UpdatedBookFeed value)) → TResult

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_UpdatedBookFeed value)?) → TResult?

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_UpdatedBookFeed value)?, {required TResult orElse()}) → TResult

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<UpdatedBook> updates, int? total, int page, int pageSize)?, {required TResult orElse()}) → TResult

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toJson() Map<String, dynamic>
Serializes this UpdatedBookFeed to a JSON map.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
when<TResult extends Object?>(TResult $default(List<UpdatedBook> updates, int? total, int page, int pageSize)) → TResult

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<UpdatedBook> updates, int? total, int page, int pageSize)?) → TResult?

Available on UpdatedBookFeed, provided by the UpdatedBookFeedPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited