List of the merchants selling this book with real-time prices
@JsonKey(readValue: _readBookReviews) List<String>? get reviews;/// List of the merchants selling this book with real-time prices List<Merchant>? get prices;