prices property

List<Merchant>? get prices
inherited

List of the merchants selling this book with real-time prices

Implementation

List<String>? get reviews;/// List of the merchants selling this book with real-time prices
List<Merchant>? get prices;