ISBNdbException class
Exception thrown when an ISBNdb API request fails.
- Implemented types
Constructors
Properties
- cause → Object?
-
Original underlying error when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error description.
final
- method → String
-
HTTP method used for the request.
final
- path → String
-
Relative API path (without base URL).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
Optional HTTP status code returned by the API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited