planName property
Name of the subscription plan attached to this key.
Empty only for legacy payloads captured before API 2.7.1.
Implementation
@JsonKey(name: 'api_host') String get apiHost;/// Name of the subscription plan attached to this key.
///
/// Empty only for legacy payloads captured before API 2.7.1.
@JsonKey(name: 'plan_name') String get planName;