updatedAt property
Timestamp when the book was last updated by ISBNdb.
Implementation
String get isbn13;/// Timestamp when the book was last updated by ISBNdb.
@JsonKey(name: 'updated_at') DateTime get updatedAt;
Timestamp when the book was last updated by ISBNdb.
String get isbn13;/// Timestamp when the book was last updated by ISBNdb.
@JsonKey(name: 'updated_at') DateTime get updatedAt;